@@ -11,28 +11,13 @@ use File::Spec;
 
 use GraphViz2;
 
-use Log::Handler;
-
 # ---------------
 
-my($logger) = Log::Handler -> new;
-
-$logger -> add
-	(
-	 screen =>
-	 {
-		 maxlevel       => 'debug',
-		 message_layout => '%m',
-		 minlevel       => 'error',
-	 }
-	);
-
 my($graph) = GraphViz2 -> new
 	(
 	 edge   => {color => 'grey'},
 	 global => {directed => 1},
 	 graph  => {rankdir => 'TB'},
-	 logger => $logger,
 	 node   => {shape => 'oval'},
 	);
 
